<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Neteja-ho tot</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation>Replega</translation>
    </message>
    <message>
        <source>More</source>
        <translation>Més</translation>
    </message>
</context>
<context>
    <name>NotifyCenter</name>
    <message>
        <source>No recent notifications</source>
        <translation>No hi ha notificacions recents.</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Centre de notificacions</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Neteja-ho tot</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation>Replega</translation>
    </message>
    <message>
        <source>More</source>
        <translation>Més</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Desancora</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Ancora</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Configuració de les notificacions</translation>
    </message>
</context>
<context>
    <name>NotifyViewDelegate</name>
    <message>
        <source>Clean All</source>
        <translation type="unfinished">Neteja-ho tot</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Ara mateix</translation>
    </message>
</context>
</TS>
